# encoding: utf-8

module MTG::API
  class Request
    class << self
      def get(path, options = {}, &block)
        response = HTTParty.get(base_uri + path, request_options(options), &block)

        if response.code == 200
          parsed_response(response)
        else
          raise "#{response.code} - #{response.message}"
        end
      end

      private

      def base_uri
        "http://mtgapi.com/api/v1/fetch"
      end

      def request_options(options)
        options.merge!(query: { token: Config.token })
      end

      def parsed_response(response)
        json = JSON.parse(response.body)

        if json.is_a?(Hash)
          Hashie::Mash.new(json)
        elsif json.is_a?(Array)
          json.map { |hash| Hashie::Mash.new(hash) }
        else
          raise "Unknown response kind."
        end
      end
    end
  end
end
